@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: bottlelib2.py,v 1.3 2011/09/25 03:36:38 atzm Exp $
+# $Id: bottlelib2.py,v 1.4 2011/09/29 12:53:39 atzm Exp $
 #
 
 import re
@@ -119,10 +119,10 @@ class BottleHTTPClient:
                 msg = res['extramessage'][0]
             raise BottleClientError('failed to get LUID', msg)
 
-        if res['luid'][0] != 82:
-            raise BottleClientError('got invalid LUID', luid)
+        if len(res['newid'][0]) != 82:
+            raise BottleClientError('got invalid LUID', res['newid'][0])
 
-        self.luid = res['luid'][0]
+        self.luid = str(res['newid'][0])
         return self.luid
 
     def get_channels(self):
