@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  loglist.py - Log list view
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -10,7 +10,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: loglist.py,v 1.6 2009/12/04 17:43:31 atzm Exp $
+# $Id: loglist.py,v 1.7 2010/08/22 11:04:07 atzm Exp $
 #
 
 import gtk, gobject
@@ -23,6 +23,7 @@ except ImportError:
 
 import config
 from common import *
+from bottlelib2 import BROADCAST_TYPE_VOTE, BROADCAST_TYPE_AGREE
 
 class LogList(gtk.TreeView):
 	LISTSTORE_PLAYING  = 0
@@ -251,9 +252,9 @@ class LogList(gtk.TreeView):
 
 	def log_votes(self, mid, type, num):
 		col = -1
-		if type == VOTE:
+		if type == BROADCAST_TYPE_VOTE:
 			col = self.LISTSTORE_VOTES
-		elif type == AGREE:
+		elif type == BROADCAST_TYPE_AGREE:
 			col = self.LISTSTORE_AGREES
 		else:
 			return
@@ -291,7 +292,7 @@ class LogList(gtk.TreeView):
 		if not res or res == gtk.RESPONSE_NO:
 			return None, None
 		elif res == gtk.RESPONSE_YES:
-			return mid, VOTE
+			return mid, BROADCAST_TYPE_VOTE
 		return None, None
 
 	def agreeing(self, widget, data, parent):
@@ -317,7 +318,7 @@ class LogList(gtk.TreeView):
 		if not res or res == gtk.RESPONSE_NO:
 			return None, None
 		elif res == gtk.RESPONSE_YES:
-			return mid, AGREE
+			return mid, BROADCAST_TYPE_AGREE
 		return None, None
 
 	def get_plain_array(self):
