@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  preferences.py - New preference manipulator for GBottler
-#  Copyright (C) 2005 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2005 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -10,11 +10,11 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: preferences.py,v 1.12 2009/12/15 17:16:50 atzm Exp $
+# $Id: preferences.py,v 1.14 2010/08/28 15:12:17 atzm Exp $
 #
 
 __author__ = '$Author: atzm $'
-__version__ = '$Revision: 1.12 $'
+__version__ = '$Revision: 1.14 $'
 
 import gtk, gobject
 
@@ -422,15 +422,17 @@ class PreferenceDialog(gtk.Dialog):
 		return frame, logwindic
 
 	def __create_network_page(self):
+		sstpframe, sstpdic = self.__create_sstp_frame()
+		httpframe, httpdic = self.__create_http_frame()
 		slppframe, slppdic = self.__create_slpp_frame()
-		sstpframe, sstpdic  = self.__create_sstp_frame()
 
 		network_page_dict = OrderedDictionary()
 		network_page_dict['sstp_server'] = sstpdic
+		network_page_dict['http_server'] = httpdic
 		network_page_dict['slpp_server'] = slppdic
 
 		network_page = gtk.VBox()
-		for widget in [sstpframe, slppframe]:
+		for widget in [sstpframe, httpframe, slppframe]:
 			network_page.pack_start(widget, False, False, 0)
 		return [network_page, network_page_dict]
 
@@ -457,6 +459,19 @@ class PreferenceDialog(gtk.Dialog):
 
 		return frame, sstpdic
 
+	def __create_http_frame(self):
+		httpdict = OrderedDictionary()
+		httpdict['http_proxy'] = gtk.Entry()
+		table = gtk.Table(2, 1)
+
+		table.attach(gtk.Label(_('HTTP Proxy')), 0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+		table.attach(httpdict['http_proxy'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
+
+		httpframe = gtk.Frame(_('HTTP Connection'))
+		httpframe.set_border_width(5)
+		httpframe.add(table)
+		return httpframe, httpdict
+
 	def __create_slpp_frame(self):
 		slppdict = OrderedDictionary()
 
@@ -464,27 +479,13 @@ class PreferenceDialog(gtk.Dialog):
 		slppdict['slpp_conn'] = gtk.Entry()
 		slppdict['slpp_port'] = gtk.SpinButton(adj1, 0, 0)
 
-		adj2 = gtk.Adjustment(0.0, 0.0, 65535.0, 1.0, 5.0, 0.0)
-		slppdict['http_conn'] = gtk.Entry()
-		slppdict['http_port'] = gtk.SpinButton(adj2, 0, 0)
-
-		slppdict['http_host'] = gtk.Entry()
-
-		table = gtk.Table(4, 3)
+		table = gtk.Table(4, 1)
 		table.attach(gtk.Label(_('SLPP Connect To')), 0, 1, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 		table.attach(slppdict['slpp_conn'], 1, 2, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 		table.attach(gtk.Label(_('SLPP Port')), 2, 3, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 		table.attach(slppdict['slpp_port'], 3, 4, 0, 1, gtk.FILL, gtk.FILL, 3, 3)
 
-		table.attach(gtk.Label(_('HTTP Connect To')), 0, 1, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
-		table.attach(slppdict['http_conn'], 1, 2, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
-		table.attach(gtk.Label(_('HTTP Port')), 2, 3, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
-		table.attach(slppdict['http_port'], 3, 4, 1, 2, gtk.FILL, gtk.FILL, 3, 3)
-
-		table.attach(gtk.Label(_('HTTP Host')), 0, 1, 2, 3, gtk.FILL, gtk.FILL, 3, 3)
-		table.attach(slppdict['http_host'], 1, 2, 2, 3, gtk.FILL, gtk.FILL, 3, 3)
-
-		slppframe = gtk.Frame(_('SLPP Server (Experimental)'))
+		slppframe = gtk.Frame(_('SLPP Connection (Experimental)'))
 		slppframe.set_border_width(5)
 		slppframe.add(table)
 		return slppframe, slppdict
