@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  queryluid.py - Query LUID information
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -10,11 +10,11 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: queryluid.py,v 1.10 2009/12/08 14:21:11 atzm Exp $
+# $Id: queryluid.py,v 1.13 2010/08/28 15:12:17 atzm Exp $
 #
 
-import sys, os, string
-import httplib
+import sys, os
+import urllib
 import htmllib, formatter
 
 import config
@@ -103,6 +103,9 @@ class LUIDParser(htmllib.HTMLParser):
 		self.headres = []
 		self.result = []
 
+class LUIDInfoURLopener(urllib.URLopener):
+	version = AGENT_NAME
+
 class LUIDInfo:
 	LUID_INFO_GENERAL = 'info'
 	LUID_INFO_DETAIL  = 'table'
@@ -111,43 +114,40 @@ class LUIDInfo:
 		self.luid   = luid
 		self.parser = LUIDParser()
 		self.cache  = LUIDCacheManager()
+		self.url    = 'http://bottle.mikage.to/luidstat.cgi'
 
 	def set_luid(self, luid):
 		self.luid = luid
 	def get_luid(self):
 		return self.luid
 
-	def get_html(self, action='/luidstat.cgi'):
+	def get_html(self):
+		proxy = config.get('http_server', 'http_proxy').strip()
+
+		if proxy:
+			proxy = {'http': proxy}
+		else:
+			proxy = None
+
 		try:
-			request = 'luid=%s' % self.luid
-
-			http = httplib.HTTP(config.get('slpp_server', 'http_conn'),
-								config.get('slpp_server', 'http_port', 'int'))
-
-			http.putrequest("POST", action)
-			http.putheader("Host", config.get('slpp_server', 'http_host'))
-			http.putheader("From", AGENT_NAME)
-			http.putheader("Accept", "text/html, text/plain")
-			http.putheader("Content-type", "application/x-www-form-urlencoded")
-			http.putheader("Content-length", str(len(request)))
-			http.endheaders()
-
-			http.send(request)
-
-			if http.getreply()[0] != 200:
-				raise RuntimeError(str(code))
-
-			html = http.getfile().read()
+			req = self.url + '?luid=' + self.get_luid()
+			fil = LUIDInfoURLopener(proxies=proxy).open(req)
+			code = fil.getcode()
+			data = fil.read()
+			fil.close()
 		except:
 			return
-		return unicode(html, 'sjis', 'ignore')
+
+		if code != 200:
+			return
+
+		return unicode(data, 'sjis', 'ignore')
 
 	def parse(self):
 		html = self.get_html()
 		if html:
 			self.parser.initialize()
 			self.parser.feed(html)
-			#print "Refreshed LUID information."
 			luid_data = {
 				self.LUID_INFO_GENERAL:  self.parser.headres,
 				self.LUID_INFO_DETAIL: self.parser.result,
@@ -216,7 +216,7 @@ class LUIDCacheManager:
 				self.luid_data[current] = []
 				continue
 
-			line = string.split(line, "\t")
+			line = line.split("\t")
 			self.luid_data[current].append(line)
 		file.close()
 
