@@ -2,7 +2,7 @@
 #
 #  svgmanager.py - The Manager of SVG
 #  Copyright (C) 2004 by Takuya KAWAHARA <num@sann.ne.jp>
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,11 +11,12 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: svgmanager.py,v 1.52 2009/12/14 14:28:56 atzm Exp $
+# $Id: svgmanager.py,v 1.55 2010/08/28 15:12:17 atzm Exp $
 
 import gtk, gobject
 import os, sys, shutil
 import string, re
+import tempfile, zipfile
 
 try:
 	import migemo
@@ -448,10 +449,43 @@ class SVGManagerWindow(gtk.Window):
 			return None
 		return None
 
+	def _extract_svg_zip(self, path):
+		tdir    = tempfile.mkdtemp(prefix='svgmanager_')
+		txtname = None
+
+		try:
+			zfile = zipfile.ZipFile(file=path, mode='r')
+
+			for n in zfile.namelist():
+				dstfile = os.path.join(tdir, n)
+				dstdir  = os.path.dirname(dstfile)
+
+				if not os.path.exists(dstdir):
+					os.makedirs(dstdir)
+
+				if os.path.isdir(dstfile):
+					continue
+
+				# XXX: must ignore all unrelated text files...
+				if dstfile.endswith('.txt') and dstfile.lower().find('readme') == -1:
+					txtname = dstfile
+
+				f = open(dstfile, 'w')
+				f.write(zfile.read(n))
+				f.close()
+
+			zfile.close()
+
+		except:
+			pass
+
+		return (txtname, tdir)
+
 ## if pressed button
 	def add_ghost(self, button):
 		ffilter = gtk.FileFilter()
 		ffilter.add_pattern('*.txt')
+		ffilter.add_pattern('*.zip')
 		filew = gtk.FileChooserDialog(parent=self, action=gtk.FILE_CHOOSER_ACTION_OPEN,
 									  buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
 											   gtk.STOCK_OK, gtk.RESPONSE_OK))
@@ -467,7 +501,22 @@ class SVGManagerWindow(gtk.Window):
 			return True
 
 		dest_dir = os.path.join(self.ghostmanager.get_basedir(), 'Ghost')
-		ghost    = self.copy_svg(src_svg_file, dest_dir)
+		ghost    = None
+
+		if src_svg_file.endswith('.zip'):
+			src_svg_file, tdir = self._extract_svg_zip(src_svg_file)
+
+			if not src_svg_file:
+				shutil.rmtree(tdir)
+				open_error_dialog(unicode(_("Couldn't open file"), 'utf-8'), self)
+				return True
+
+			ghost = self.copy_svg(src_svg_file, dest_dir)
+			shutil.rmtree(tdir)
+
+		else:
+			ghost = self.copy_svg(src_svg_file, dest_dir)
+
 		if not ghost:
 			sys.stderr.write("!!! couldn't copy %s\n" % src_svg_file)
 			return True
