@@ -3,7 +3,7 @@
 #
 #  ghost.py - The Ghost
 #  Copyright (C) 2004 by Takuya KAWAHARA <num@sann.ne.jp>
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -12,10 +12,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: ghost.py,v 1.23 2009/12/15 18:45:55 atzm Exp $
+# $Id: ghost.py,v 1.25 2011/09/24 15:29:49 atzm Exp $
 #
 
-__version__ = '$Revision: 1.23 $'
+__version__ = '$Revision: 1.25 $'
 __author__ = '$Author: atzm $'
 
 import gtk
@@ -39,8 +39,6 @@ def _debugprint(desc, text):
 
 class Ghost:
 	def __init__(self, path):
-		_debugprint('Ghost def text', path)
-
 		self.path           = path           # abspath
 		self.splite_dic     = {}             # surface_id -> splite_id
 		self.surface_dic    = {}             # splite_id  -> surface_id
@@ -185,7 +183,8 @@ class Ghost:
 					last_surf = self._get_surface_pixbuf(int(splt))
 					surfaces.append(last_surf)
 				except ValueError:
-					_debugprint('Invalid sequence contains', str(splite_id))
+					_debugprint('Invalid sequence contains',
+								'[%s] "%s"' % (self.path, str(splite_id)))
 
 		return surfaces
 
@@ -257,7 +256,7 @@ class Ghost:
 				keyval = line.split('=', 1)
 
 				if len(keyval) != 2:
-					_debugprint('Invalid line(1)', line)
+					_debugprint('Invalid line(1)', '[%s] "%s"' % (self.path, line))
 					continue
 
 				key = keyval[0].strip()
@@ -268,14 +267,14 @@ class Ghost:
 
 				elif key == 'sequential':
 					if not self._parse_sequential(val):
-						_debugprint('Invalid sequential', line)
+						_debugprint('Invalid sequential', '[%s] "%s"' % (self.path, line))
 
 				elif key == 'alias':
 					if not self._parse_alias(val):
-						_debugprint('Invalid alias', line)
+						_debugprint('Invalid alias', '[%s] "%s"' % (self.path, line))
 
 				else:
-					_debugprint('Invalid line(2)', line)
+					_debugprint('Invalid line(2)', '[%s] "%s"' % (self.path, line))
 
 				continue
 
@@ -291,11 +290,11 @@ class Ghost:
 				keyval = d.split(':', 1)
 
 				if len(keyval) != 2:
-					_debugprint('Invalid surface defs(1)', d)
+					_debugprint('Invalid surface defs(1)', '[%s] "%s"' % (self.path, d))
 					continue
 
 				if not keyval[0] or not keyval[1]:
-					_debugprint('Invalid surface defs(2)', d)
+					_debugprint('Invalid surface defs(2)', '[%s] "%s"' % (self.path, d))
 					continue
 
 				surf_id, splt_id = keyval
